package cv4
  connector pq
    Real p;
    flow Real q;
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2}), graphics = {Polygon(origin = {-1.12, -5.87}, fillPattern = FillPattern.Solid, points = {{-72.5265, 83.6508}, {63.029, 85.2381}, {94.4576, -1.746}, {52.5528, -85.2381}, {-58.8757, -84.9206}, {-94.4313, 0.793683}, {-72.5265, 83.6508}})}));
  end pq;

  model psrc
    parameter Real p;
    cv4.pq pq1 annotation(Placement(visible = true, transformation(origin = {0, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {0, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    pq1.p = p;
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2}), graphics = {Polygon(origin = {2.7, 6.12}, fillColor = {210, 169, 21}, fillPattern = FillPattern.Solid, points = {{-88.4125, 83.7197}, {-89.0474, -8.97868}, {-2.69817, -83.8993}, {85.8733, -21.9946}, {89.0479, 76.7356}, {-88.4125, 83.7197}})}));
  end psrc;

  model resist
    parameter Real R;
    Real dp;
    parameter Real L;
    cv4.pq pq1 annotation(Placement(visible = true, transformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-80, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    cv4.pq pq2 annotation(Placement(visible = true, transformation(origin = {80, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {80, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    dp = pq1.p - pq2.p;
    dp = R * pq1.q;
    pq1.q + pq2.q = 0;
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2}), graphics = {Rectangle(origin = {-1.9, 3.02}, fillColor = {207, 46, 46}, fillPattern = FillPattern.HorizontalCylinder, extent = {{-83.81, 32.86}, {83.81, -32.86}})}));
  end resist;

  model resist2
    parameter Real R;
    Real dp;
    parameter Real L;
    Real limitedR;
    Real risingR;
    Real highR;
    cv4.pq pq1 annotation(Placement(visible = true, transformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-80, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    cv4.pq pq2 annotation(Placement(visible = true, transformation(origin = {80, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {80, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    // zpusob 1 - pokud zas risingR klesne pod 6, tak nam klesne i hodnota limitedR
    dp = pq1.p - pq2.p;
    dp = limitedR * pq1.q;
    risingR = R * (1 + (time - 5) * 1);
    highR = if time < 5 then R else risingR;
    limitedR = if risingR > 6 then 6 else risingR;
    pq1.q + pq2.q = 0;
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2}), graphics = {Rectangle(origin = {-1.9, 3.02}, fillColor = {207, 246, 46}, fillPattern = FillPattern.HorizontalCylinder, extent = {{-83.81, 32.86}, {83.81, -32.86}})}));
  end resist2;

  model resist3
    parameter Real R;
    Real dp;
    parameter Real L;
    Real limitedR;
    Real risingR;
    Boolean highLimit(start = false);
    discrete Real highR(start = -1);
    cv4.pq pq1 annotation(Placement(visible = true, transformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-80, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    cv4.pq pq2 annotation(Placement(visible = true, transformation(origin = {80, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {80, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    // zpusob 2 / jakmile prorazime horni hranici, tak uz se nevratime zpet
    risingR = limitedR * (1 + (time - 5) * 1);
    when highR > 6 then
      highLimit = true;
      risingR = highR;
    end when;
    if time < 5 then
      limitedR = R;
    elseif highLimit then
      limitedR = highR;
    else
      limitedR = risingR;
    end if;
    dp = pq1.p - pq2.p;
    dp = R * pq1.q;
    pq1.q + pq2.q = 0;
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2}), graphics = {Rectangle(origin = {-1.9, 3.02}, fillColor = {7, 246, 46}, fillPattern = FillPattern.HorizontalCylinder, extent = {{-83.81, 32.86}, {83.81, -32.86}})}));
  end resist3;

  model systemRes
    cv4.psrc psrc1(p = 1) annotation(Placement(visible = true, transformation(origin = {-80, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    cv4.psrc psrc2(p = 0) annotation(Placement(visible = true, transformation(origin = {60, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    cv4.resist resist1(R = 1) annotation(Placement(visible = true, transformation(origin = {0, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(resist1.pq2, psrc2.pq1) annotation(Line(points = {{8, 0}, {59.3651, 0}, {59.3651, 32.0635}, {59.3651, 32.0635}}));
    connect(resist1.pq1, psrc1.pq1) annotation(Line(points = {{-8, 0}, {-80.3175, 0}, {-80.3175, 32.0635}, {-80.3175, 32.0635}}));
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})), Diagram(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})));
  end systemRes;

  model systemRes2
    cv4.psrc psrc1(p = 1) annotation(Placement(visible = true, transformation(origin = {-80, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    cv4.psrc psrc2(p = 0) annotation(Placement(visible = true, transformation(origin = {60, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    cv4.resist2 resist1(R = 1) annotation(Placement(visible = true, transformation(origin = {0, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(resist1.pq2, psrc2.pq1) annotation(Line(points = {{8, 0}, {59.3651, 0}, {59.3651, 32.0635}, {59.3651, 32.0635}}));
    connect(resist1.pq1, psrc1.pq1) annotation(Line(points = {{-8, 0}, {-80.3175, 0}, {-80.3175, 32.0635}, {-80.3175, 32.0635}}));
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})), Diagram(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})));
  end systemRes2;

  model systemRes3
    cv4.psrc psrc1(p = 1) annotation(Placement(visible = true, transformation(origin = {-80, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    cv4.psrc psrc2(p = 0) annotation(Placement(visible = true, transformation(origin = {60, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    cv4.resist3 resist1(R = 1) annotation(Placement(visible = true, transformation(origin = {0, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(resist1.pq2, psrc2.pq1) annotation(Line(points = {{8, 0}, {59.3651, 0}, {59.3651, 32.0635}, {59.3651, 32.0635}}));
    connect(resist1.pq1, psrc1.pq1) annotation(Line(points = {{-8, 0}, {-80.3175, 0}, {-80.3175, 32.0635}, {-80.3175, 32.0635}}));
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})), Diagram(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})));
  end systemRes3;

  model chlopen
    cv4.pq pq1 annotation(Placement(visible = true, transformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    cv4.pq pq2 annotation(Placement(visible = true, transformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Real dp, s, q;
    Boolean on;
  equation
    q = pq1.q;
    dp = pq1.p - pq2.p;
    pq1.q + pq2.q = 0;
    s > 0 = on;
    if on then
      dp = 0;
      s = q;
    else
      dp = s;
      q = 0;
    end if;
    annotation(Diagram(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2}), graphics = {Polygon(origin = {-1.5, 2.85}, fillColor = {21, 162, 42}, fillPattern = FillPattern.Solid, points = {{-92.7832, 86.3543}, {-94.053, -86.3441}, {94.5184, -3.8044}, {78.9628, 6.03687}, {-92.7832, 86.3543}})}));
  end chlopen;

  model komora
    cv4.pq pq1 annotation(Placement(visible = true, transformation(origin = {0, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {0, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput c annotation(Placement(visible = true, transformation(origin = {-80, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-80, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Real V;
  equation
    der(V) = pq1.q;
    pq1.p = c * V;
    annotation(Diagram(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2}), graphics = {Ellipse(origin = {-0.16, 5.24}, fillColor = {196, 19, 19}, fillPattern = FillPattern.Solid, extent = {{55.08, -86.19}, {-55.08, 86.19}}, endAngle = 360)}));
  end komora;

  model PumpingHeart
    cv4.psrc psrc1(p = 1) annotation(Placement(visible = true, transformation(origin = {-100, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    cv4.psrc psrc2(p = 2) annotation(Placement(visible = true, transformation(origin = {80, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    cv4.chlopen chlopen1 annotation(Placement(visible = true, transformation(origin = {40, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    cv4.resist resist2(R = 1) annotation(Placement(visible = true, transformation(origin = {80, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    cv4.chlopen chlopen2 annotation(Placement(visible = true, transformation(origin = {-40, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    cv4.resist resist1(R = 1) annotation(Placement(visible = true, transformation(origin = {-80, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    cv4.komora komora1 annotation(Placement(visible = true, transformation(origin = {0, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.Sine sine1(freqHz = 1, offset = 1) annotation(Placement(visible = true, transformation(origin = {-40, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(resist2.pq2, psrc2.pq1) annotation(Line(points = {{88, 20}, {94.2857, 20}, {94.2857, 51.746}, {80.3175, 51.746}, {80.3175, 51.4286}, {80.3175, 51.4286}}));
    connect(chlopen1.pq2, resist2.pq1) annotation(Line(points = {{50, 20}, {70.4762, 20}, {70.4762, 20.3175}, {70.4762, 20.3175}}));
    connect(resist1.pq1, psrc1.pq1) annotation(Line(points = {{-88, 20}, {-100.635, 20}, {-100.635, 50.7937}, {-100.635, 50.7937}}));
    connect(chlopen2.pq1, resist1.pq2) annotation(Line(points = {{-50, 20}, {-72.0635, 20}, {-72.0635, 20.3175}, {-72.0635, 20.3175}}));
    connect(chlopen1.pq1, chlopen2.pq2) annotation(Line(points = {{30, 20}, {-30.4762, 20}, {-30.4762, 20}, {-30.4762, 20}}));
    connect(komora1.pq1, chlopen1.pq1) annotation(Line(points = {{0, 52}, {29.5238, 52}, {29.5238, 20.3175}, {29.5238, 20.3175}}));
    connect(sine1.y, komora1.c) annotation(Line(points = {{-29, 80}, {-8.57143, 80}, {-8.57143, 67.619}, {-8.57143, 67.619}}, color = {0, 0, 127}));
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})), Diagram(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})));
  end PumpingHeart;
  annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})), Diagram(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})));
end cv4;